#!/usr/bin/python3.7
# -*- coding: utf-8 -*-
# @Time  : 2019/6/5 9:36
# @Author: Jtyoui@qq.com
from .SearchAlgorithm import *  # 搜索算法
from .MatchingAlgorithm import *  # 匹配算法
from .SortAlgorithm import *  # 排序算法
from .ReplaceAlgorithm import *  # 替换算法
from .TreeAlgorithm import *  # 创建树算法
