#!/usr/bin/python3.7
# -*- coding: utf-8 -*-
# @Time  : 2019/3/25 18:18
# @Author: Jtyoui@qq.com

from .AnalysisMath import AnalysisMath, cov  # 分析
from .matrix import Matrix  # 矩阵
from .target import *  # 分类预测
