#!/usr/bin/python3.7
# -*- coding: utf-8 -*-
# @Time  : 2019/3/21 9:52
# @Author: Jtyoui@qq.com

from .distance import *  # 两点之间的距离
from .coefficient import *  # 相关系数
from .analysis import *  # 分析数学
from .dr import *  # 降维
from .clustering import *  # 聚类
from .maths import *  # 数学类
