#!/usr/bin/python3.7
# -*- coding: utf-8 -*-
# @Time    : 2019/7/17 21:30
# @Email  : jtyoui@qq.com
# @Software: PyCharm
from enum import Enum


class FileFormat(Enum):
    """文件格式介绍"""
    A = "对象代码库文件"
    AAM = "Author ware shocked文件"
    AAS = "Author ware shocked包"
    ABF = "Adobe二进制屏幕字体"
    ABK = "CorelDRAW自动备份文件"
    ABS = "该类文件有时用于指示一个摘要（就像在一篇有关科学方面的文章的一个摘要或概要，取自abstract）"
    ACE = "Ace压缩文件格式"
    ACM = "Windows系统目录文件"
    ACP = "Microsoft office助手预览文件"
    ACT = "Microsoft office助手文件"
    AD = "AfterDark屏幕保护程序"
    ADA = "Ada源文件（非-GNAT）"
    ADB = "Ada源文件主体（GNAT）；HP100LX组织者的约定数据库"
    ADF = "Amiga磁盘文件"
    ADI = "AutoCAD设备无关二进制绘图仪格式"
    ADM = "AfterDark多模块屏幕保护；WindowsNT策略模板"
    ADP = "FaxWork用于传真调制解调器的交互安装文件；AstoundDynamite文件"
    ADR = "AfterDark随机屏幕保护；SmartAddress的地址簿"
    ADS = "Ada源文件说明书（GNAT）"
    AFM = "Adobe的字体尺度"
    AF2 = "ABC的FlowChat文件"
    AF3 = "ABC的FlowChat文件"
    AI = "AdobeIllustrator格式图形"
    AIF = "音频互交换文件，SiliconGraphicandMacintosh应用程序的声音格式"
    AIFF = "音频互交换文件，SiliconGraphicandMacintosh应用程序的声音格式"
    AIFC = "压缩AIF"
    AIM = "AOL即时信息传送"
    AIS = "ACDSee图形序列文件；VelvetStudio设备文件"
    AKW = "RoboHELP的帮助工程中所有A-关键词"
    ALB = "JASCImageCommander相册"
    ALL = "艺术与书信库"
    AMS = "VelvetStudio音乐模块（MOD）文件；Extreme的Tracker模块文件"
    ANC = "CanonComputer的调色板文件，包含一系列可选的颜色板"
    ANI = "Windows系统中的动画光标"
    ANS = "ANSI文本文件"
    ANT = "SimAntForWindows中保存的游戏文件"
    API = "AdobeAcrobat使用的应用程序设计接口文件"
    APS = "MicrosoftVisualC++文件"
    APK = "安卓安装包"
    ARI = "Aristotle声音文件"
    ARJ = "RobertJungARJ压缩包文件"
    ART = "XaraStudio绘画文件；CanonCrayola美术文件；ClipArt文件格式；另一种光线跟踪格式；AOL使用的用Johnson-Grace压缩算法压缩的标记文件"
    ASA = "MicrosoftVisualInterDev文件"
    ASC = "ASCⅡ文本文件；PGP算法加密文件"
    ASD = "Microsoft Word的自动保存文件；Microsoft高级流媒体格式的描述文件；可用NSREX打开VelvetStudio例子文件"
    ASE = "VelvetStudio采样文件"
    ASF = "Microsoft高级流媒体格式文件"
    ASM = "汇编语言源文件，Pro/E装配文件"
    ASO = "AstoundDynamite对象文件"
    ASP = "动态网页文件；ProCommPlus安装与连接脚本文件；Astound介绍文件"
    ASV = "DataCAD自动保存文件"
    ASX = "Cheyenne备份脚本文件；Microsoft高级流媒体重定向器文件，视频文件"
    ATW = "来自个人软件的AnyTimeDeluxeForWindows个人信息管理员文件"
    AU = "Sun/NeXT/DEC/UNIX声音文件；音频U-Law（读作“mu-law”）文件格式"
    AVB = "ComputerAssociatesInoculan反病毒软件的病毒感染后文件"
    AVI = "MicrosoftAudioVideoInterleave电影格式"
    AVR = "AudioVisualResearch文件格式"
    AVS = "应用程序可视化格式"
    AWD = "FaxVien文档"
    AWR = "Telsis数字储存音频文件扩展名格式"
    Axx = "ARJ压缩文件的分包序号文件，用于将一个大文件压至几个小的压缩包中（xx取01-99的数字）"
    A3M = "Author ware Macintosh未打包文件"
    A4M = "Author ware Macintosh未打包文件"
    A4P = "Author ware无运行时间的打包文件"
    A3W = "未打包的Author ware Windows文件"
    A4W = "未打包的Author ware Windows文件"
    A5W = "未打包的Author ware Windows文件"
    BAK = "备份文件"
    BAS = "BASIC源文件"
    BAT = "批处理文件"
    BDF = "WestPointBridgerDesigner文件"
    BGL = "MicrosoftFlightSimulator（微软飞行模拟器）的视景文件"
    BI = "二进制文件"
    BIF = "GroupWise的初始化文件"
    BIFF = "XLIFE3D格式文件"
    BIN = "二进制文件"
    BK = "有时用于代表备份版本"
    BKS = "IBMBookManagerRead书架文件"
    BMK = "书签文件"
    BMP = "Windows或OS/2位图文件"
    BOOK = "AdobeFrameMakerBook文件"
    BRX = "用于查看多媒体对象目录的文件"
    BSP = "Quake图形文件"
    BTM = "Norton应用程序使用的批处理文件"
    BUD = "Quicken的备份磁盘"
    BUN = "CakeWalk声音捆绑文件（一种MIDI程序）"
    BW = "SGI黑白图像文件"
    BWV = "商业波形文件"
    C = "C代码文件"
    CAB = "Microsoft压缩文件"
    CAD = "Softdek的DrafixCAD文件"
    CAL = "CALS压缩位图；日历计划表数据"
    CAP = "压缩音乐文件格式"
    CAS = "逗号分开的ASCⅡ文件"
    CB = "Microsoft干净引导文件"
    CC = "VisualdBASE用户自定义类文件"
    CCB = "VisualBasic动态按钮配置文件"
    CCH = "Corel图表文件"
    CCO = "CyberChat数据文件"
    CCT = "MacromediaDirectorShockwave投影"
    CDA = "CD音频轨道"
    CDF = "Microsoft频道定义格式文件"
    CDI = "Philip的高密盘交互格式"
    CDM = "VisualdBASE自定义数据模块文件"
    CDR = "CorelDRAW绘图文件；原始音频CD数据文件"
    CDT = "CorelDRAW模板"
    CDX = "CorelDRAW压缩绘图文件；MicrosoftVisualFoxPro索引文件"
    CFG = "配置文件"
    CGI = "公共网关接口脚本文件"
    CGM = "计算机图形元文件"
    CHK = "由Windows磁盘碎片整理器或磁盘扫描保存的文件碎片"
    CHM = "编译过的HTML文件"
    CHR = "字符集（字体文件）"
    CIF = "AdaptecCD创建器CD映像文件"
    CIL = "ClipGallery下载包"
    CLASS = "Java类文件"
    CLL = "CrickSoftwareClicker文件"
    CLP = "Windows剪贴板文件"
    CLS = "VisualBasic类文件"
    CMF = "Corel元文件"
    CMV = "CorelMove动画文件"
    CMX = "CorelPresentationExchange图像"
    CNF = "Telnet，Windows和其他其内格式会发生改变的应用程序使用的配置文件"
    CNM = "Windows应用程序菜单选项和安装文件"
    CNT = "Windows（或其他）系统用于帮助索引或其他目的内容文件"
    COD = "MicrosoftC编译器产生的可显示机器码/汇编代码文件，其中附有源C代码作为注释"
    COM = "命令文件（程序）"
    CPL = "控制面板扩展名，Corel颜色板"
    CPO = "Corel打印存储文件"
    CPP = "C++代码文件"
    CPR = "Corel提供说明书文件"
    CPT = "Corel照片-绘画图像"
    CPX = "CorelPresentationExchange压缩图形文件"
    CRD = "WindowsCardfile文件"
    CRP = "Corel提供的运行时介绍文件；VisualdBASE自定义报表文件"
    CRT = "认证文件"
    CSC = "Corel脚本文件"
    CSP = "PCEmceeOn_Screen图像"
    CST = "MacromediaDirectorCast文件"
    CSV = "逗号分隔的值文件"
    CTL = "通常用于表示一个包含控件信息的文件；FaxWork用它来保持有关每个传真收到或发出的信息"
    CUR = "Windows光标文件"
    CV = "Corel版本的档案文件；MicrosoftCodeView信息屏幕文件"
    CXX = "C++源代码文件"
    DAT = "数据文件；WrodPerfect合并数据文件；用于一些MPEG格式的文件"
    DB = "Borland的Paradox7表"
    DBC = "MicrosoftVisualFoxPro数据库容器文件"
    DBF = "dBASE文件"
    DBX = "DataBearn图像；MicrosoftVisualFoxPro表格文件"
    DCM = "DCM模块格式文件"
    DCS = "桌面颜色分隔文件"
    DCT = "MicrosoftVisualFoxPro数据库容器"
    DCU = "Delphi编译单元文件"
    DCX = "MicrosoftVisualFoxPro数据库容器；基于PCX的传真图像；宏"
    DEM = "用于表示数字高度模型的USGS基准的文件"
    DER = "认证文件"
    DEWF = "MacintoshSoundCap/SoundEdit录音设备格式"
    DIB = "设备无关位图"
    DIC = "目录"
    DIF = "可进行数据互换的电子表格"
    DIG = "DigiLink格式；SoundDesignerⅠ音频文件"
    DIR = "MacromediaDirector文件"
    DIZ = "描述文件"
    DLG = "C++对话框脚本文件"
    DLL = "动态链接库"
    DLS = "可下载声音文件"
    DMD = "VisualdBASE数据模块文件"
    DMF = "X-Trakker音乐模块（MOD）文件"
    DOC = "Word文档"
    DOT = "MicrosoftWord文档模板"
    DRAW = "Acorn的基于对象的矢量图像文件"
    DRV = "驱动程序"
    DRW = "MicrografxDesigner/Draw；Pro/E绘画文件"
    DSF = "MicrografxDesignerVFX文件"
    DSG = "DOOM保存的文件"
    DSM = "DynamicStudio音乐模块（MOD）文件"
    DSP = "MicrosoftDeveloperStudio工程文件"
    DSQ = "CorelQUERY（查询）文件"
    DSW = "MicrosoftDeveloperStudio工作区文件"
    DTD = "SGML文档类型定义（DTD）文件"
    DUN = "Microsoft拔号网络导出文件"
    DV = "数字视频文件（MIME）"
    DXF = "可进行互交换的绘图文件格式，二进制的DWG格式的文本表示；数据交换文件"
    DXR = "MacromediaDirector受保护（不可编辑）电影文件"
    EDA = "EnsoniqASR磁盘映像"
    EDD = "元素定义文档（FrameMaker+SGML文档）"
    EMD = "ABT扩展模块"
    EMF = "Windows增强元文件"
    EML = "MicrosoftOutlookExpress邮件消息（MIMERFC822）文件"
    EPHTML = "Perl解释增强HTML文件"
    EPS = "压缩的PostScript图像"
    EXE = "可执行文件（程序）"
    FAV = "MicrosoftOutlook导航条"
    FAX = "传真类型图像"
    FCD = "虚拟CD-ROM"
    FDF = "AdobeAcrobat表单文档文件"
    FFA = "Microsoft快速查找文件"
    FFL = "Microsoft快速查找文件"
    FFO = "Microsoft快速查找文件"
    FFK = "Microsoft快速查找文件"
    FIF = "Fractal图像文件"
    FLA = "MacromediaFlash电影"
    FLC = "AutodeskFLIC动画文件"
    PLI = "AutodeskFLIC动画"
    FM = "AdobeFrameMaker文档"
    FML = "文件镜象列表（GetRight）"
    FNG = "字体组文件（字体导航器，FontNavigator）"
    FNK = "FunkTracker模块格式"
    FON = "系统字体"
    FOT = "字体相关文件"
    FRT = "MicrosoftFoxPro报表文件"
    FRX = "VisualBasic表单文本；MicrosoftFoxPro报表文件"
    FTG = "全文本搜索组文件，由Windows帮助系统查找时产生--可以删除，并在需要时重建起来"
    FTS = "全文本搜索引文件，由Windows帮助系统查找时产生"
    GAL = "Corel多媒体管理器相集"
    GDB = "InterBase数据库文件"
    GDM = "铃声、口哨声和声音板模块格式"
    GEM = "GEM元文件"
    GEN = "Ventura产生的文本文件"
    GetRight = "GetRight未完成的下载文件"
    GFI = "Genigraphics图形链接表示文件"
    GFX = "Genigraphics图形链接表示文件"
    GHO = "Norton克隆磁盘映像"
    GIF = "CompuServe位图文件"
    GIM = "Genigraphics图形链接介绍文件"
    GIX = "Genigraphics图形链接介绍文件"
    GKH = "EnsoniqEPS家簇磁盘映像文件"
    GKS = "GravisGripKey文档"
    GL = "动画格式"
    GNA = "Genigraphics图形链接介绍文件"
    GNT = "生成代码，MicroFocus属性格式里的可执行代码"
    GNX = "Genigraphics图形链接介绍文件"
    GRA = "MicrosoftGraph文件"
    GRF = "Grapher（GoldenSoftware公司）图形文件"
    GRP = "程序管理组"
    GO = "Go语言源文件"
    HCOM = "声音工具HCOM格式"
    HGL = "HP图形语言绘图文件"
    HLP = "帮助文件；DateCADWindows帮助文件"
    HPJ = "VisualBasic帮助工程"
    HPP = "C++程序头文件"
    HST = "历史文件"
    HT = "HyperTerminal（超级终端）"
    HTM = "超文本文档"
    HTML = "超文本文档"
    HTT = "Microsoft超文本模板"
    HTX = "扩展HTML模板"
    ICB = "Targa位图文件"
    ICC = "Kodak打印机格式文件"
    ICL = "图标库文件"
    ICM = "图形颜色匹配配置文件"
    ICO = "Windows图标"
    IDD = "MIDI设备定义"
    IDF = "MIDI设备定义（Windows95需要的文件）"
    IDQ = "Internet数据查询文件"
    IDX = "MicrosoftFoxPro相关数据库索引文件；SymantecQ&A相关数据库索引文件；MicrosoftOutlookExpress文件"
    IFF = "交换格式文件；AmigaILBM"
    IGES = "初始图形交换说明文件"
    IGF = "插入系统元文件"
    ILBM = "位图图形文件"
    IMA = "WinImage磁盘映像文件"
    INF = "信息文件"
    INI = "初始化文件"
    INRS = "INRS远程通信声频"
    INS = "InstallShield安装脚本"
    INT = "中间代码，当一个源程序经过语法检查后编译产生一个可执行代码"
    IQY = "MicrosoftInternet查询文件"
    ISO = "根据ISD9660有关CD-ROM文件系统标准列出CD-ROM上的文件"
    IST = "数字跟踪设备文件"
    ISU = "InstallShield卸装脚本"
    IWC = "InstallWatch文档"
    J62 = "Ricoh照相机格式"
    JAR = "Java档案文件"
    JAVA = "Java源文件"
    JBF = "PaintShopPro图像浏览文件"
    JFF = "JPEG文件"
    JFIF = "JPEG文件"
    JIF = "JPEG文件"
    JMP = "SAS的JMPDiscovery表格统计文件"
    JPE = "JPEG图形文件"
    JPEG = "JPEG图形文件"
    JPG = "JPEG图形文件"
    JS = "Javascript源文件"
    JSP = "HTML网页，其中包含有对一个Javaservlet的参考"
    JSON = "Json文件"
    JTF = "JPEG位图文件"
    K25 = "Kurzweil2500抽样文件"
    KAR = "卡拉OKMIDI文件"
    KDC = "Kodak光增强器"
    KEY = "DataCAD图标工具条文件"
    KFX = "KoFakGroup4图像文件"
    KIZ = "Kodak数字明信片文件"
    KKW = "RoboHELP帮助工程索引设计器中与主题无关的K开头的所有关键字"
    KMP = "KorgTrinityKeyMap文件"
    KQP = "Konica照相机本地文件"
    LAB = "VisualdBASE标签文件"
    LBM = "DeluxePaint位图文件"
    LBT = "MicrosoftFoxPro标签文件"
    LBX = "MicrosoftFoxPro标签文件"
    LDB = "MicrosoftAccess加锁文件"
    LDL = "CorelParadox分发库"
    LEG = "Legacy文档"
    LFT = "3DStudio（DOS）放样文件"
    LGO = "Paintbrush（Microsoft画图应用程序）的徽标文件"
    LHA = "LZH更换文件后缀"
    LIB = "库文件"
    LIN = "DataCAD线型文件"
    LIS = "结构化查询报告（SQR）程序产生的输出文件"
    LLX = "Laplink交换代理"
    LNK = "Windows快捷方式文件"
    LOG = "日志文件"
    LST = "列表文件"
    LU = "ThoughtWing库单元文件"
    LYR = "DataCAD层文件"
    LZH = "LHARC压缩档案"
    LZS = "Skyroads数据文件"
    M1V = "MPEG相关文件（"
    M3U = "MPEGURL（MIME声音文件）"
    MAD = "MicrosoftAccess模块文件"
    MAF = "MicrosoftAccess表单文件"
    MAM = "MicrosoftAccess宏"
    MAP = "映射文件；DukeNukem3DWAD游戏文件"
    MAQ = "MicrosoftAccess查询文件"
    MAR = "MicrosoftAccess报表文件"
    MAT = "MicrosoftAccess表；3DStudioMAX材料库"
    MB1 = "ApogeeMonsterBash数据文件"
    MBX = "MicrosoftOutlook保存email格式；Eudora邮箱"
    MCR = "DataCAD键盘宏文件"
    MDB = "MicrosoftAccess数据库"
    MDE = "MicrosoftAccessMDE文件"
    MDL = "数字跟踪器音乐模块（MOD）文件；Quake模块文件"
    MDN = "MicrosoftAccess空数据库模板"
    MDW = "MicrosoftAccess工作组文件"
    MDZ = "MicrosoftAccess向导模板文件"
    MIC = "MicrosoftImageComposer文件"
    MID = "MIDI音乐"
    MIM = "MIME，MMEInternet邮件扩展格式的多用途文件，经常作为发送e-mail时在AOL里附件而创建的文件；在一个多区MIM文件里的文件能用WinZip或其他类似程序打开"
    MLI = "3DStudio的材料库格式文件"
    MNG = "多映像网络图形"
    MNU = "VisualdBASE菜单文件；IntertelSystemsInteract菜单文件"
    MOD = "FastTracker、StarTrekker、NoiseTracker（等等）音乐模块文件；Microsoft多计划电子表格；Amiga/PC磁道文件"
    MOV = "QuickTimeforWindows电影"
    MP2 = "第二层MPEG音频文件"
    MP3 = "第三层MPEG音频文件"
    MPA = "MPEG相关文件，MIME“mpeg类型”"
    MPE = "MPEG动画文件"
    MPEG = "MPEG动画文件"
    MPG = "MPEG动画文件"
    MPP = "Microsoft工程文件；CAD绘图文件格式"
    MPR = "MicrosoftFoxPro菜单（已编译）"
    MSG = "Microsoft邮件消息"
    MSI = "Windows安装文件包"
    MSN = "Microsoft网络文档；DescentMission文件"
    MSP = "MicrosoftPaint（画图）位图文件；WindowsInstaller路径文件"
    MST = "Windows安装器传输文件"
    MTM = "Multi跟踪器音乐模块（MOD）文件"
    NAN = "Nanoscope文件（RawGrayscale）"
    NAP = "NAP元文件"
    NCB = "MicrosoftDeveloperStudio文件"
    NCD = "Norton改变目录"
    NCF = "NetWare命令文件；LotusNotes内部剪切板"
    NFF = "中性文件格式"
    NFT = "NetObjectFusion模板文件"
    NIL = "Norton光标库文件（EasyIcons-兼容）"
    NIST = "NISTSphere声音"
    NLS = "用于本地化的国家语言支持文件（例如，Uniscape）"
    NLU = "NortonLiveUpdatee-mail触发器文件"
    NTX = "CA-Clipper索引文件"
    NWC = "NoteworthyComposer歌曲文件"
    NWS = "MicrosoftOutlookExpress新闻消息"
    OBJ = "对象文件"
    OCX = "Microsoft对象链接与嵌入定制控件"
    ODS = "MicrosoftOutlookExpress邮箱文件"
    OFN = "MicrosoftOfficeFileNew文件"
    OFT = "MicrosoftOutlook模板"
    OLB = "OLE对象库"
    OLE = "OLE对象"
    OOGL = "面向对象图形库"
    OPO = "OPL输出可执行文件"
    P65 = "PageMaker6.5文件"
    PAB = "Microsoft个人地址簿"
    PART = "Zilla部分下载文件"
    PAS = "Pascal源代码"
    PY = "Python源代码"
    PYC = "Python字节码文件"
    PYW = "Python图形窗口文件"
    PBD = "PowerBuilder动态库，作为本地DLL的一个替代物"
    PBL = "用于在PowerBuilder开发环境中的PowerBuilder动态库"
    PBM = "可导出位图"
    PBR = "PowerBuilder资源"
    PCD = "KodakPhoto-CD映像；P-Code编译器测试脚本，由Microsoft测试与MicrosoftVisual测试"
    PCL = "Hewlett-Packard打印机控制语言文件（打印机备用位图）"
    PCM = "声音文件格式；OKIMSM6376合成芯片PCM格式"
    PDD = "可以用PaintShopPro或其他图像处理软件打开的图形图像"
    PDF = "AdobeAcrobat可导出文档格式文件（可用Web浏览器显示）；Microsoft系统管理服务器包定义文件；NetWare打印机定义文件"
    PFM = "打印机字体尺度"
    PGL = "HP绘图仪绘图文件"
    PGM = "可输出灰度图（位图）"
    PH = "由Microsoft帮助文件编译器产生的临时文件"
    PHP = "包含有PHP脚本的HTML网页"
    PHP3 = "包含有PHP脚本的HTML网页"
    PHTML = "包含有PHP脚本的HTML网页；由Perl分析解释的HTML"
    PIC = "PC画图位图；Lotus图片；MacintoshPICT绘图"
    PJX = "MicrosoftVisualFoxPro工程文件"
    PJT = "MicrosoftVisualFoxPro工程文件"
    PKG = "MicrosoftDeveloperStudio应用程序扩展（与DLL文件类似）"
    PNG = "可移植的网络图形位图；PaintShopPro浏览器目录"
    POT = "MicrosoftPowerpoint模块"
    PPA = "MicrosoftPowerpoint内插器"
    PPF = "TurtleBeach的Pinnacle程序文件"
    PPM = "可移植的象素映射位图"
    PPS = "MicrosoftPowerpoint幻灯片放映"
    PPT = "MicrosoftPowerpoint演示文稿"
    PRF = "Windows系统文件，Macromedia导演设置文件"
    PRG = "dBASEClipper和FoxPro程序源文件；WAVmaker程序"
    PRJ = "3DStudio（DOS）工程文件"
    PRN = "打印表格（用空格分隔的文本）；DataCADWindows打印机文件"
    PRT = "打印格式化文件；Pro/ENGINEER元件文件"
    PSD = "Adobephotoshop位图文件"
    PSP = "PaintShopPro图像文件"
    PST = "MicrosoftOutlook个人文件夹文件"
    PWZ = "MicrosoftPowerpoint向导"
    QIC = "Microsoft备份文件"
    QIF = "QuickTime相关图像（MIME）；Quicken导入文件"
    QLB = "Quick库"
    QRY = "Microsoft查询文件"
    QTP = "QuickTime优先文件"
    QTX = "QuickTime相关图像"
    QW = "SymantecQ&AWrite程序文件"
    RA = "RealAudio声音文件"
    RAM = "RealAudio元文件"
    RAR = "RAR压缩档案（EugeneRoshall格式）"
    RDF = "资源描述框架文件（涉及XML和元数据）"
    REG = "注册表文件"
    REP = "VisualdBASE报表文件"
    RES = "MicrosoftVisualC++资源文件"
    RFT = "可修订的表单文本（IBM的DCA一部分或文档内容框架结构一部分）"
    RGB = "Silicon图形RGB文件"
    SGI = "Silicon图形RGB文件"
    RM = "RealAudio视频文件"
    RMD = "MicrosoftRegMaid文档"
    RPT = "MicrosoftVisualBasicCrystal报表文件"
    RTF = "RichText格式文档"
    RUL = "InstallShield使用的扩展名"
    RVP = "MicrosoftScan配置文件（MIME）"
    S = "汇编源代码文件"
    SAV = "游戏保存文件"
    SBL = "ShockwaveFlash对象文件"
    SCC = "MicrosoftSourceSafe文件"
    SCF = "WindowsExplorer命令文件"
    SCP = "拨号网络脚本文件"
    SCR = "Windows屏幕保护；传真图像；脚本文件"
    SCT = "SAS目录（DOS）；ScitexCT位图；MicrosoftFoxPro表单"
    SCX = "MicrosoftFoxPro表单文件"
    SDT = "SmartDraw模板"
    SDV = "分号分隔的值文件"
    SDX = "由SDX压缩的MIDI抽样转储标准文件"
    SEP = "标签图像文件格式（TIFF）位图"
    SFD = "SoundStage声音文件数据"
    SFI = "SoundStage声音文件信息"
    SFR = "SonicFoundrySample资源"
    SFX = "RAR自解压文件"
    SGML = "标准通用标签语言"
    SHG = "热点位图"
    SHTML = "含有服务器端包括（SSI）的HTML文件"
    SHW = "CorelShow演示文稿"
    SIG = "符号文件"
    SKA = "PGP秘钥"
    SKL = "Macromedia导演者资源文件"
    SL = "PACT的保存布局扩展名"
    SO = "Linux的共享库"
    SPL = "ShockwaveFlash对象；DigiTrakker抽样"
    SQC = "结构化查询语言（SQR）普通代码文件"
    SQR = "结构化查询语言（SQR）程序文件"
    STR = "屏幕保护文件"
    SWA = "在Macromedia导演文件（MP3文件）中的Shockwave声音文件"
    SWF = "ShockwaveFlash对象"
    SYS = "系统文件"
    SYW = "YamahaSY系列波形文件"
    TAZ = "UNIXgzip/tape档案"
    TGA = "Targa位图"
    THEME = "Windows桌面主题文件"
    THN = "GraphicsWorkShopforWindows速写"
    TIF = "标签图像文件格式（TIFF）位图"
    TIFF = "标签图像文件格式（TIFF）位图"
    TIG = "虎形文件，美国政府用于分发地图"
    TLB = "OLE类型库"
    TMP = "Windows临时文件"
    TOL = "Kodak照片增强器"
    TPL = "CakeWalk声音模板文件；DataCAD模板文件"
    TRM = "终端文件"
    TRN = "MKS源完整性工程用法日志文件"
    TTF = "TrueType字体文件"
    TXT = "ASCⅡ文本格式的声音数据"
    TXW = "YamahaTX16W波形文件"
    UDF = "WindowsNT/2000唯一性数据库文件"
    ULT = "UltraTracker音乐模块（MOD）文件"
    URL = "Internet快捷方式文件"
    USE = "MKS源完整性文件"
    UWF = "Ultraracker波形文件"
    VBP = "MicrosoftVisualBasic工程文件"
    VBS = "MicrosoftVisualBasic脚本语言"
    VBW = "MicrosoftVisualBasic工作区文件"
    VBX = "MicrosoftVisualBasic用户定制控件"
    VCT = "MicrosoftFoxPro类库"
    VCX = "MicrosoftFoxPro类库"
    VDA = "Targa位图"
    VIR = "NortonAnti-Virus或其他杀毒产品用于标识被病毒感染的文件"
    VIV = "VivoActivePlayer流视频文件"
    VSD = "Visio绘画文件（流程图或图解）"
    VSL = "下载列表文件（GetRight）"
    VSS = "Visio模板文件"
    VST = "Targa位图"
    VSW = "Visio工作区文件"
    VXD = "MicrosoftWindows虚拟设备驱动程序"
    VQF = "YamahaSound-VQ文件（可能出现标准）"
    W3L = "W3Launch文件"
    WAB = "MicrosoftOutlook文件"
    WAD = "包含有视频、玩家水平和其他信息的DOOM游戏的大文件"
    WAV = "Windows波形声形"
    WBK = "MicrosoftWord备份文件"
    WCM = "WordPerfect宏"
    WDB = "MicrosoftWorks数据库"
    WFM = "VisualdBASEWindows表单"
    WFN = "在CorelDRAW中使用的符号"
    WIL = "WinImage文件"
    WIZ = "MicrosoftWord向导"
    WLL = "MicrosoftWord内插器"
    WMF = "Windows元文件"
    WOW = "GraveComposer音乐模块（MOD）文件"
    WP = "WordPerfect文档"
    WPD = "WordPerfect文档或演示"
    WPF = "可字处理文档"
    WPG = "WordPerfect图形"
    WPS = "MicrosoftWorks文档"
    WPT = "WordPerfect模板"
    WR1 = "书写器文档"
    WRK = "Cakewalk音乐声音工程文件"
    WRL = "虚拟现实模型"
    WRZ = "VRML文件对象"
    X = "AVS图像格式"
    XAR = "CorelXARA绘画"
    XBM = "MIME“xbitmap”图像"
    XI = "ScreamTracker设备抽样文件"
    XLA = "MicrosoftExcel内插器"
    XLB = "MicrosoftExcel工具条"
    XLC = "MicrosoftExcel图表"
    XLD = "MicrosoftExcel对话框"
    XLK = "MicrosoftExcel备份"
    XLL = "MicrosoftExcel内插器文件"
    XLM = "MicrosoftExcel宏"
    XLS = "MicrosoftExcel工作单"
    XLT = "MicrosoftExcel模板"
    XLV = "MicrosoftExcelVBA模块"
    XLW = "MicrosoftExcel工作簿/工作区"
    XNK = "MicrosoftExchange快捷方式文件"
    XPM = "X位图格式"
    XWD = "XWindows转储格式"
    XWF = "YamahaXGWorks文件（MIDI序列）"
    X16 = "宏媒体扩展（程序扩展），16位"
    X32 = "宏媒体扩展（程序扩展），32位"
    YAL = "Arts&Letters剪贴艺术库"
    Z = "UNIX gzip文件"
    ZAP = "Windows软件安装配置文件"
    ZIP = "Zip文件"


if __name__ == '__main__':
    print(FileFormat.FFA.name, FileFormat.FFA.value)
