#!/usr/bin/python3.7
# -*- coding: utf-8 -*-
# @Time  : 2019/11/7 10:14
# @Author: Jtyoui@qq.com
"""这个包都是一些机器学习的用例算法，不提供使用！"""
from .common import *  # 机器学习常见的函数
from .testdata import *  # 训练和测试数据集合
from .neighbor import *  # 增加KNN算法
