#!/usr/bin/python3.7
# -*- coding: utf-8 -*-
# @Time  : 2019/7/28 1:14
# @Author: jtyoui@qq.com
from .ernie import st as ernie_st, match as ernie_match, ERNIE_MODEL_PARAMETER, ERNIE_LABEL_MAP  # 实体识别
