#!/usr/bin/python3.7
# -*- coding: utf-8 -*-
# @Time : 2019/2/11
# @Email : jtyoui@qq.com
# @Software : PyCharm
from .CantorTernarySet import CantorTernarySet  # 康托三分集
from .KochSnowflake import draw_koch  # 科赫雪花
