#!/usr/bin/python3.7
# -*- coding: utf-8 -*-
# @Time    : 2019/4/28 21:56
# @Email  : jtyoui@qq.com
# @Software: PyCharm

from .Encyclopedias import BaiDuInfoSearch, Load_BaiDuBaiKe  # 百度百科搜索基本信息
from .baiduwenku import BaiDuWenKu  # 增加百度文库下载
