#!/usr/bin/python3.7
# -*- coding: utf-8 -*-
# @Time : 2019/2/2 0002
# @Email : jtyoui@qq.com
# @Software : PyCharm
from .AutoChat import auto_start  # 自动聊天机器人
from .Movie import movie_start  # 自动爬取电影机器人
