#!///3.7
# -*- : -8 -*-
# @  : 2019/10/11 15:05
# @: @.

SurName = """
赵 钱 孙 李 周 吴 郑 王 冯 陈 褚 卫
蒋 沈 韩 杨 朱 秦 尤 许 何 吕 施 张
孔 曹 严 华 金 魏 陶 姜 戚 谢 邹 喻
柏 水 窦 章 云 苏 潘 葛 奚 范 彭 郎
鲁 韦 昌 马 苗 凤 花 方 俞 任 袁 柳
酆 鲍 史 唐 费 廉 岑 薛 雷 贺 倪 汤
滕 殷 罗 毕 郝 邬 安 常 乐 于 时 傅
皮 卞 齐 康 伍 余 元 卜 顾 孟 平 黄
和 穆 萧 尹 姚 邵 湛 汪 祁 毛 禹 狄
米 贝 明 臧 计 伏 成 戴 谈 宋 茅 庞
熊 纪 舒 屈 项 祝 董 梁 杜 阮 蓝 闵
席 季 麻 强 贾 路 娄 危 江 童 颜 郭
梅 盛 林 刁 锺 徐 邱 骆 高 夏 蔡 田
樊 胡 凌 霍 虞 万 支 柯 昝 管 卢 莫
经 房 裘 缪 干 解 应 宗 丁 宣 贲 邓
郁 单 杭 洪 包 诸 左 石 崔 吉 钮 龚
程 嵇 邢 滑 裴 陆 荣 翁 荀 羊 於 惠
甄 麴 家 封 芮 羿 储 靳 汲 邴 糜 松
井 段 富 巫 乌 焦 巴 弓 牧 隗 山 谷
车 侯 宓 蓬 全 郗 班 仰 秋 仲 伊 宫
宁 仇 栾 暴 甘 钭 历 戎 祖 武 符 刘
景 詹 束 龙 叶 幸 司 韶 郜 黎 蓟 溥
印 宿 白 怀 蒲 邰 从 鄂 索 咸 籍 赖
卓 蔺 屠 蒙 池 乔 阳 郁 胥 能 苍 双
闻 莘 党 翟 谭 贡 劳 逄 姬 申 扶 堵
冉 宰 郦 雍 却 璩 桑 桂 濮 牛 寿 通
边 扈 燕 冀 僪 浦 尚 农 温 别 庄 晏
柴 瞿 阎 充 慕 连 茹 习 宦 艾 鱼 容
向 古 易 慎 戈 廖 庾 终 暨 居 衡 步
都 耿 满 弘 匡 国 文 寇 广 禄 阙 东
欧 殳 沃 利 蔚 越 夔 隆 师 巩 厍 聂
晁 勾 敖 融 冷 訾 辛 阚 那 简 饶 空
曾 毋 沙 乜 养 鞠 须 丰 巢 关 蒯 相
查 后 荆 红 游 竺 权 逮 盍 益 桓 公
万俟 司马 上官 欧阳 夏侯 诸葛 闻人 东方 赫连 皇甫 尉迟 公羊
澹台 公冶 宗政 濮阳 淳于 单于 太叔 申屠 公孙 仲孙 轩辕 令狐
钟离 宇文 长孙 慕容 司徒 司空 召 有 舜 叶赫那拉 丛 岳
寸 贰 皇 侨 彤 竭 端 赫 实 甫 集 象
翠 狂 辟 典 良 函 芒 苦 其 京 中 夕
之 章佳 那拉 冠 宾 香 果 依尔根觉罗 依尔觉罗 萨嘛喇 赫舍里 额尔德特
萨克达 钮祜禄 他塔喇 喜塔腊 讷殷富察 叶赫那兰 库雅喇 瓜尔佳 舒穆禄 爱新觉罗 索绰络 纳喇
乌雅 范姜 碧鲁 张廖 张简 图门 太史 公叔 乌孙 完颜 马佳 佟佳
富察 费莫 蹇 称 诺 来 多 繁 戊 朴 回 毓
税 荤 靖 绪 愈 硕 牢 买 但 巧 枚 撒
泰 秘 亥 绍 以 壬 森 斋 释 奕 姒 朋
求 羽 用 占 真 穰 翦 闾 漆 贵 代 贯
旁 崇 栋 告 休 褒 谏 锐 皋 闳 在 歧
禾 示 是 委 钊 频 嬴 呼 大 威 昂 律
冒 保 系 抄 定 化 莱 校 么 抗 祢 綦
悟 宏 功 庚 务 敏 捷 拱 兆 丑 丙 畅
苟 随 类 卯 俟 友 答 乙 允 甲 留 尾
佼 玄 乘 裔 延 植 环 矫 赛 昔 侍 度
旷 遇 偶 前 由 咎 塞 敛 受 泷 袭 衅
叔 圣 御 夫 仆 镇 藩 邸 府 掌 首 员
焉 戏 可 智 尔 凭 悉 进 笃 厚 仁 业
肇 资 合 仍 九 衷 哀 刑 俎 仵 圭 夷
徭 蛮 汗 孛 乾 帖 罕 洛 淦 洋 邶 郸
郯 邗 邛 剑 虢 隋 蒿 茆 菅 苌 树 桐
锁 钟 机 盘 铎 斛 玉 线 针 箕 庹 绳
磨 蒉 瓮 弭 刀 疏 牵 浑 恽 势 世 仝
同 蚁 止 戢 睢 冼 种 涂 肖 己 泣 潜
卷 脱 谬 蹉 赧 浮 顿 说 次 错 念 夙
斯 完 丹 表 聊 源 姓 吾 寻 展 出 不
户 闭 才 无 书 学 愚 本 性 雪 霜 烟
寒 少 字 桥 板 斐 独 千 诗 嘉 扬 善
揭 祈 析 赤 紫 青 柔 刚 奇 拜 佛 陀
弥 阿 素 长 僧 隐 仙 隽 宇 祭 酒 淡
塔 琦 闪 始 星 南 天 接 波 碧 速 禚
腾 潮 镜 似 澄 潭 謇 纵 渠 奈 风 春
濯 沐 茂 英 兰 檀 藤 枝 检 生 折 登
驹 骑 貊 虎 肥 鹿 雀 野 禽 飞 节 宜
鲜 粟 栗 豆 帛 官 布 衣 藏 宝 钞 银
门 盈 庆 喜 及 普 建 营 巨 望 希 道
载 声 漫 犁 力 贸 勤 革 改 兴 亓 睦
修 信 闽 北 守 坚 勇 汉 练 尉 士 旅
五 令 将 旗 军 行 奉 敬 恭 仪 母 堂
丘 义 礼 慈 孝 理 伦 卿 问 永 辉 位
让 尧 依 犹 介 承 市 所 苑 杞 剧 第
零 谌 招 续 达 忻 六 鄞 战 迟 候 宛
励 粘 萨 邝 覃 辜 初 楼 城 区 局 台
原 考 妫 纳 泉 老 清 德 卑 过 麦 曲
竹 百 福 言 第五 佟 爱 年 笪 谯 哈 墨
南宫 赏 伯 佴 佘 牟 商 西门 东门 左丘 梁丘 琴
后 况 亢 缑 帅 微生 羊舌 海 归 呼延 南门 东郭
百里 钦 鄢 汝 法 闫 楚 晋 谷梁 宰父 夹谷 拓跋
壤驷 乐正 漆雕 公西 巫马 端木 颛孙 子车 督 仉 司寇 亓官
鲜于 锺离 盖 逯 库 郏 逢 阴 薄 厉 稽 闾丘
公良 段干 开 光 操 瑞 眭 泥 运 摩 伟 铁 迮
荔菲 辗迟
""".strip().split()

_message = """
    赵：造父为周穆王驾车，穆王把赵城赐了给他，其后代以国为姓。赵匡胤是宋代的开国皇帝，据说赵姓放在第一位与此有关。
    钱：彭祖的孙子彭孚在西周朝廷中任钱府上士，其后人以其官为姓。
    孙：周文王的一后代叫惠孙，他的后代以他的名字“孙”作为姓。
    李：皋陶的后人理征因得罪纣王被处死，其妻儿在一棵李子树下摘果充饥得以活命，其后人为纪念李子的救命之恩改为“李”姓。
    周：相传黄帝时就有一位叫周昌的大将，至商代又有一名叫周任的太史，这两个人的后代都以周为姓氏，还有以周文王或者周公的部分后人也以周为姓，以及唐朝时为避唐玄宗名讳，姬姓改为周姓。
    吴：周太王亶父之子太伯、仲雍建立吴国，其子孙称为吴氏。
    郑：郑桓公遗族以国名为姓。
    王：出自姬姓，为周文王第十五子毕公高的后代。
    冯：毕公高的后人就以封地为姓。
    陈：最早出自妫姓，胡公满的子孙们以国为姓。
    褚：恭段受封于褚邑，子孙就都以“褚”为姓。
    卫：周文王的第九个儿子叫康叔，建立了卫国，他的后代以国名为姓。
    蒋：周武王的兄弟伯龄，被封到“蒋”，公族子孙以国名为姓。
    沈：周文王的第十个儿子叫季载，成立沈国。沈国君主的后代都以沈为姓。
    韩：周时贵族武子，受封于韩原，子姓以地名为姓：战国时的韩国，被秦国并，原韩国王族世代姓韩。
    杨：上古时候，周宣王的儿子尚父，封到杨邑，称做杨侯，建杨国，子孙用杨姓。
    朱：西周时，周武王封曹侠到邾，后代以地名为姓，写作朱。
    秦：上古的非子善于驯养马匹，被周孝王封为秦地的首领，建立了秦国。其后人以国为姓。
    尤：尤姓是由沈姓而来。
    许：远古炎帝的后代。文叔建立了许国，后代就以许为姓。
    何：春秋战国时，韩国的公族中有一支迁移至江淮，以国为姓。
    吕：炎帝后代伯夷被封为吕侯，他的后代就用吕作为姓。
    施：夏朝时，有诸侯国，称施国，今湖北恩施县，其后代姓施。
    张：春秋时晋国贵族叫解张，他的后代用他的名作为姓。
    孔：开国君主叫天乙，后将乙字和子字并拢，形成孔字，定为姓。
    曹：远古有一贵族叫“安”，帮助大禹治水，被恩赐给一个曹姓。
    严：严姓是由庄姓变来。
    华：西周时候，宋国公子，受封于“华”，他的子孙后来就以地名为姓。
    金：远古黄帝的儿子少昊的后代以金为姓。
    魏：毕万的后代毕斯建起魏国，称魏文侯，其后人以国为姓。
    陶：尧的子孙中，有人以制陶为荣耀，就姓陶，世代延续。
    姜：以地名为姓。
    戚：以地名为姓。
    谢：用地名做姓。
    邹：最早出自姚姓，以地名为姓。姓名名典《姓觽》：邹国，舜后，姚姓。舜帝后裔姚姓族人开创建有邹国，是最早的邹国。
    喻：远古黄帝时，有个医官叫俞柎，为喻姓祖先。
    柏：柏姓起源非常古老，黄帝有个孙子叫颛顼，他的老师就姓柏。
    水：水姓是大禹的后代，大禹治水，他的族人都当水工，后来就以水为姓。
    窦：大禹的后代，纪念先人。
    章：部落得一姓，其中就有章姓。
    云：黄帝的后代。
    苏：远古贵族昆吾，因为封在苏城为首领，就以地名为姓。
    潘：季孙的后代就以潘为姓。
    葛：最早的葛姓源于葛天氏。
    奚：奚姓是黄帝的子孙。
    范：贵族士会，被晋国国君封为范邑的首领，他的子孙就以地名为姓。
    彭：大彭国的创建者篯铿，就是彭祖。
    郎：地名为姓。
    鲁：周公旦的儿子伯禽受封于鲁地，后来鲁国的王公贵族都以鲁为姓。
    韦：韦姓的一支是韩信的后代。
    昌：始祖昌意，是黄帝的儿子。
    马：赵奢受封马服君，他的子孙姓马。
    苗：春秋时期的贲皇享用苗邑的物产，就以地名为姓。
    凤：黄帝的后代帝喾有个大臣叫凤鸟氏，主管历法天文，其后代以凤为姓。
    花：花姓人物最早的是花木兰，传说是南北朝人。
    方：神农氏的后代中有一位叫榆罔，其儿子受封方山后叫方雷，方雷的子孙就以地名为姓。
    俞：黄帝时，有个名医叫俞跗，是俞姓的始祖。
    任：黄帝的小儿子叫禺阳，受封于任邑。其子孙以任为姓。
    袁：周朝伯辕的后代将辕省去左半边，作为姓。
    柳：春秋时期展禽，改姓了柳下，史书上称他柳下季，柳姓由此开头。
    酆：周武王将弟弟封于酆邑，他的后代以地名为姓。
    鲍：春秋时期敬叔在齐国做官，受封于鲍邑，后代就以鲍为姓。
    史：黄帝有一名史官叫仓颉，后代以其官职为姓，就形成了史姓。仓颉被中国人尊为造字的圣人。
    唐：远古时，尧曾经在“唐”那个地方做首领。尧的族人就有以地名为姓。
    费：春秋时期，鲁国有个人物叫父，因有功劳受封为费邑的首领，现今山东鱼台县费亭一带，他的子孙就以地名为姓，世代延续。
    廉：远古黄帝的玄孙叫大廉，大廉的后代形成了廉姓。
    岑：周朝岑子建岑国，岑国的公族子孙，以国名为姓。
    薛：薛登的后代以薛为姓。
    雷：黄帝的一个妻子姓方雷，雷姓由此而来。
    贺：贺姓由庆姓转变来。
    倪：倪氏本为郳氏，因避仇改为倪。
    汤：汤王的后代有人就以祖先的名为姓。
    滕：周武王封弟弟叔绣封于滕国，后代子孙以国名为姓。
    殷：源出于子姓。
    罗：源于熊姓，是以国为名的姓。
    毕：毕公高的后代以国名为姓，称为毕氏。
    郝：源于子姓，是伏羲氏的后裔。
    邬：古帝颛顼后裔陆终氏第四子求言（妘姓）别封于邬，后代子孙以邬为姓。
    安：源自始祖。
    常：出自姬姓。
    乐：乐源出于子姓，西周末，公子衎字乐父，他的孙子以祖父字中“乐”命氏，称为乐氏。
    于：源出于姬姓。周武王的第三个儿子叔分封在邘国，与冯姓相同，后代去邑为姓，称为于氏。
    时：春秋时齐国贤士时子的后代以其名字中的“时”为姓。
    傅：黄帝裔孙大由封于傅邑，其后代以地名为姓。
    皮：樊仲皮的后人以他字中的“皮”为姓。
    卞：西周时，曹叔振铎的子孙分封在卞，他的后代称为卞氏。
    齐：齐康公后人，称为齐氏。
    康：源于谥号。
    伍：春秋时，楚庄王有个宠臣名叫伍参，是楚公族的后人。庄王封伍参为大夫，称为伍氏。
    余：春秋时，晋人由余穆公重用，他为穆公出谋划策，攻灭西戎十二国，使秦国成为西方霸主。他的后世子孙以其名字中的“余”为姓，称为余氏。
    元：春秋时，因卫国大夫元的封地在元，其后世子孙即以元为姓。
    卜：卜姓是古代从事占卜者的后代。
    顾：夏朝附庸国顾国，顾国为商汤所灭后，原王公族人以国名为姓。
    孟：春秋时，卫国国君叫卫襄公，卫襄公的儿子叫公孟。公孟的子孙有的姓公孟，有的省去公字而姓孟。
    平：战国末期，韩哀侯之子婼封于平邑。秦灭韩后，婼率族人迁居于下邑，他的孙子以原封地命姓。
    黄：出自赢姓，为陆终的后裔。
    和：祝融氏重黎的后人羲和的后代。
    穆：意为贤良、和气。
    萧：萧国后代子孙以国名为姓。
    尹：上古少昊氏的后裔。
    姚：舜因最初在姚墟，他的后裔子孙即以地为姓。
    邵：周文王第五子召公奭（音），食邑于召子孙遂以召为氏，后加邑为邵。
    湛：夏代早期，斟灌氏国后人以国为姓。
    汪：汪姓出自汪芒氏。
    祁：源自姬姓。
    毛：以封邑名作为姓的。
    禹：人名命名。
    狄：狄族的子孙后代就以族名作为自己的姓。
    米：春秋时代，楚国的后代当中有了米姓。
    贝：周文王的后代召公康，后代以国名为姓。
    明：古代部落首领燧人氏有一个重臣叫明由，他的后世子孙以其名作为姓。
    臧：鲁孝公儿子驱，他的后代以封地名作为自己的姓。
    计：禹后人的封地，后人便以国名。
    伏：伏姓出自风姓。
    成：出自姬姓。
    戴：宋戴公的后裔以他的谥号为姓。
    谈：出自子姓，是殷商皇族的后裔。
    宋：出自子姓，起源于战国时期。
    茅：周公旦的第三个儿子名叔，受封于茅邑，子孙以国名为姓。
    庞：出自高阳氏。黄帝的孙子颛顼生有八个儿子，其中有一个儿子名叫庞降，他的后人就以他的名字作为姓。
    熊：传说黄帝曾在有熊建都，所以黄帝的后代中有人以都城为姓。
    纪：出自姜姓。西周时，炎帝裔孙被封于纪，建立纪国，因属侯爵，所以被称作纪侯。纪国为齐国所灭，纪侯子孙便以国名为姓。纪姓另有一支由舒姓改成。
    舒：周朝封皋陶的后代于舒（今安徽庐江县西），建立舒国，曾被徐国所灭，后又复国，不久又亡于楚国，其国君族人以舒为姓。
    屈：是夏代屈骜的后代。
    项：春秋时期，楚国公子燕受封于项城（今河南项城县），建立项国。后项国被齐国所灭，其子孙以国名为姓。
    祝：周武王封黄帝的己姓后裔在祝国（今山东临沂县东南），后代子孙以国名为姓。
    董：相传黄帝后裔董父被舜帝封于鬷川，并赐以董姓，其子孙沿习为姓。
    梁：西周时，周宣王封秦仲二儿子康在夏阳梁山（今陕西韩城附近）立国为君，为梁康伯。后梁国为秦国所灭，其后代便以梁为姓。
    杜：舜封尧之子丹朱于唐。周成王时，唐国因不服王命被灭，成王改封唐国后人于杜（今西安市东杜陵）。宣王执政后，杜国君在朝任大夫，人称杜伯。杜伯因得罪了宣王的宠妃，被宣王屈杀。杜伯子孙大多逃往中原，留在杜城的一支以杜为姓。杜姓另一支为北魏时期鲜卑人独孤浑氏改姓。
    阮：出自偃姓。东夷族首领皋陶的后人在商朝时被封在泾水与渭水之间的阮国（今甘肃泾川县东南），商末时被周文王所灭，国人便以阮为姓。
    蓝：梁惠王三年，秦子向命封邑在蓝田，他的子孙以地名为姓。
    闵：源于姬姓。
    席：为籍姓所改。
    季：颛顼后裔陆终的第三个儿子为季连，他的后代以排行为姓。
    麻：春秋时期，熊婴做了齐国的大夫，他以祖先食邑为姓，改姓麻，史称麻婴。
    强：强姓出自姜姓，炎帝的后裔。
    贾：周朝康王时，封唐叔虞的小儿子公明于贾（今山西襄汾西南），称贾伯，他的后代以贾为姓。
    路：古代传说中黄帝后裔玄元，因有功，被封为路中侯，他的好几代子孙都延承这个爵称，后来渐渐变成了这个氏族的姓。他的后代以路为姓。
    娄：源于姒姓，是大禹的后代。周武王灭商后，把夏帝少康的后代东楼公封于杞国（河南杞县）。至春秋时期，杞国在周围大国的威胁下被迫东迁，杞君有一支子孙被封在娄邑（今山东诸城西南），后来以娄为姓。
    危：三苗族原居于河南南部至洞庭湖、鄱阳湖一带，三苗后裔以危为姓。
    江：出自嬴姓。颛顼裔孙伯益之后被封在江（今河南正阳西南），江国后来被楚国灭掉，国人便以江为姓。
    童：相传古帝颛顼有个儿子叫老童，他的后代以祖上名字为姓，称童氏。
    颜：古帝玄孙陆终第五子名安，周武王封其后裔挟于邾（今山东曲阜南陬村），后有邾武公名夷父，字颜，称之谓颜公。他的后代以祖字为姓，称颜氏。
    郭：姬序号为虢公，因虢与郭同音，转化变音，其后代便称为郭姓。
    梅：梅姓出于子姓，是商汤的后裔，发源于今天的安徽省亳州东南。
    盛：源出有三:出自姬姓，出自组名为氏，出自少数民族改姓。
    林：出自子姓，是商汤的后代。
    刁：出自姬姓。
    钟：伯宗的儿子伯州食邑在钟离，其后人以钟离作为姓，后简称钟。
    徐：出自赢姓，发源于今天的安徽省泗县。
    邱：出自姜姓，发源于今天的山东省昌乐。
    骆：出自姜姓。姜太公的后代有一个名叫公子骆，他的后世子孙以他的字作为姓，这样就有了骆姓。
    高：一支源于远古时代高台宫殿的建筑者，其始祖是黄帝时的大臣高元。
    夏：源于姒姓，是大禹的后裔。
    蔡：源自姬姓，发源于今天的河南省上蔡西南。
    田：西周初年，周武王封大禹的后代胡公满于陈（今河南省境内），并且建立了陈国，其后代都以陈作为姓。
    樊：出自姬姓，发源于今天的河南省济源县。
    胡：源于姬姓和归姓。
    凌：出自姬姓，发源于今天的河北省。
    霍：出自姬姓，发源于今天的山西省霍县西南。周武王在位时封叔武于霍，并且建立了霍国，世称叔武为霍叔，春秋时霍国被晋献公所灭，此后，霍国王室的后世子孙便以国名为姓。
    虞：最早出自姚姓，舜的儿子商均封于虞城，建立诸侯国虞国，其后世子孙便以国名作为自己的姓。
    万：出自姬姓，发源于今天的山西省芮城。
    支：来源比较复杂，而且模糊。传说尧舜时期有一个叫支父的人，他的子孙后代以支为姓。
    柯：出自姜姓，发源于齐国（今山东境内），是传说中炎帝的后裔，为姜子牙的嫡系子孙。
    昝：是由咎姓发展而来的。
    管：出自姬姓，发源于今天的河南省郑州市。
    卢：出自姜姓，发源于今天山东省的长清县。
    莫：出自高阳氏，发源于今天河北省任丘北部。
    经：春秋时，郑国公子共叔段被封于京（今河南荥阳县东南），其后代以封邑为姓。
    房：舜帝后来封丹朱的儿子陵于房国，陵的子孙便以地名为姓。
    裘：春秋时，卫国一大夫受封于裘，他的后代以封邑为姓，称裘氏。
    缪：古代“穆”与“缪”同音通用，所以春秋五霸之一的秦穆公也称作秦缪公，他的庶子以谥号命姓，称缪氏。
    干：春秋时，宋国有个大夫叫干，他的后代以他名字中的“干”字为姓，称干氏。
    解：出自姬姓，周朝贵族良的封地在解（今山西解县），他的子孙以地名为姓，称解氏。
    应：周武王克商后，封他的第四子于应（今河南鲁山县境内），他的后代以封地为姓，称应氏。
    宗：周朝时设有辅佐天子掌管宗室之事的春官，春秋时鲁国改称宗伯，负责宗庙祭祀礼仪，有世袭此职者，其后代便以“宗”为姓。
    丁：周朝时，姜子牙的儿子伋死后谥号为丁公，他的子孙以谥号为姓，称丁氏。
    宣：出自于谥号。
    贲：贲姓有十起源：一是来自鲁国县贲父的后代：一是来自戎族氏族：一是来自晋国苗贲父的后代：一是来自秦国嬴姓的后代：一是来自两周时期特殊称谓等等。贲还有一个姓的读音为，今不多见。
    邓：殷王武丁封他的叔父于邓国的曼城，称曼氏，后来又改封邓国。
    郁：古时有郁国，春秋时为吴国大夫的封邑，其国人多为郁姓。春秋时鲁国有宰相郁贡，他的后人以郁为姓，称郁氏。
    单：源出于姬姓。
    杭：源出于姒姓，是大禹的后代。
    洪：共工氏后人因先辈曾负责治水之职，便给共字加水旁，作为自己的姓。
    包：春秋后期，楚国有个大夫叫申包胥，他的子孙以他名字中的“包”字为姓。
    诸：春秋时，鲁国大夫受封于诸（今山东诸城西南），其后裔以封邑为姓，称诸氏。西汉时，历代名人有：无诸被封闽越王，他的后代以其名字中的“诸”为姓。五代后周人诸葛十朋，在赵匡胤陈桥兵变，黄袍加身后，不愿做宋朝臣民，隐居在会稽山。
    左：周朝史官有左、右之分，左史记言，右史记事。世袭左史之职的后人便以官职为姓。
    石：石厚的儿子石骀仲以祖父的字命姓，称石氏。
    崔：春秋时，齐丁公之子季子，把君位让给了兄弟叔乙，自己去了崔邑（今山东章丘），从此称为崔氏。
    吉：周宣王时有个大臣叫做尹吉甫，因赫赫军功而闻名，他的后代以他名字中的“吉”字为姓，称为吉氏。
    钮：《名贤氏族言行类稿》载，东晋有钮滔，其后为钮姓。
    龚：姬和，因封地被称为共（河南辉县）伯，子孙因国命姓，古时“共”、“龚”同音通用，后来传为龚
    程：颛顼有两个孙子重和黎，西周建立以后，重和黎的后代被封于程，并且建立了程国，后代以国为姓。
    嵇：嵇姓出自姒姓。
    邢：邢姓出自姬姓。
    滑：滑姓出自姬姓。
    裴：裴姓出自赢姓。
    陆：陆姓发源于今天的山东省平原县一带。
    荣：黄帝时，有一个叫荣援的人，黄帝封他为诸侯，并且建立了荣国，他曾经奉黄帝之命铸钟十二个，其后世子孙都以荣为姓。
    翁：在夏朝初年，有一位贵族叫翁难乙，他可以说是翁姓的始祖。
    荀：荀姓出自姬姓。
    羊：西周有一个种官职叫羊人，担任这个官职之人的后世子孙，就以此为姓，这样就有了羊姓。
    於：发源于今天的河南省。
    惠：远古时期的部落联合首领颛顼的后代叫惠连，他的后代子孙就以“惠”作为自己的姓，这样就有了惠姓。
    甄：上古部落首领皋陶的次子名仲甄，在夏朝时为卿仕，受封于甄，他的后裔也取姓为甄。
    麴：麴本是酿酒的主要原料，西周时成为掌管酿酒业的官名，世袭此职的人便以麴为姓。
    家：源自于姬姓。
    封：炎帝的后代，以地为姓。
    芮：源于姬姓。周武王封姬良夫于芮，后人以国为姓。
    羿：为夏朝著名弓箭射手后羿的后代。
    储：相传上古时有储国，储国人的后代以储为姓。
    靳：战国时期靳尚的后代便以靳为姓。
    汲：源自于姬姓。春秋时期，卫宣公的公子居住的地方叫汲（今河南汲县），他的后代以汲为姓。
    邴：齐大夫邴的封地也叫邴（今山东费县东南），他的后代以封邑为姓，也称邴氏，也有去邑成姓，称丙氏。
    糜：最早始于夏代，是以谷物名称命名的姓。
    松：起源于秦朝。
    井：源自姜姓。
    段：春秋时，老子李聃的孙子李宗在晋国为官，封于段干，他的后代一支姓段。
    富：周襄王时有姬姓大夫名富辰，直言敢谏，不避贵胄，为人称道，他的后代有的以其名字为姓，称富氏。
    巫：担任巫官后人有的以巫字为姓。
    乌：出自金天氏。
    焦：神农氏的后人，以国为姓。
    巴：战国中期，巴国被秦国攻灭，巴人便以国名为姓。
    弓：来源为职官名。
    牧：力牧助黄帝治理天下，立有大功，他的后代便以祖上名字为姓，一支姓力，一支姓牧。
    隗和：汤灭夏桀后，封其后人于隗，建大隗国，春秋时为楚国所灭，其子孙以国名为姓，称隗氏。春秋时晋国大举进攻赤狄诸部落，赤狄人后裔汉化后沿用隗姓。
    山：周朝掌管山林的官员叫山师，子孙便称为山氏。
    谷：源自于嬴姓。
    车：春秋时，秦国大夫子车仲的后代为车姓。
    侯：春秋时，晋哀侯和缗侯均为晋武公所杀，哀侯和缗侯的子孙逃难他国后，便以祖上受封爵位为姓，称侯氏。
    宓或：音时是安静的意思。读，古同“伏”，“伏羲”亦作“宓羲”。
    蓬：源自姬姓。
    全：泉府官的后人以职官为姓，便有了泉姓，又因“全”、“泉”同音通用，于是也便有了全姓。
    郗：苏忿生的后代受封于郗（今河南沁阳），其后人便以封邑命姓为郗姓。
    班：春秋时，楚国若敖的孙子出生后曾被母亲弃于野外，吃虎乳长大。因虎有斑纹，其后代子孙以此事件命姓，为班姓。
    仰：仰姓一支出自舜帝时大臣仰延之后。
    秋：秋姓为少昊氏之后。
    仲：商汤王左相仲虺的后代和春秋时宋庄公之子（字子仲）的后代，也以祖上名字为姓。
    伊：相传尧出生在伊祁山，他的后代有的以伊为姓。
    宫：周朝时有专门负责宫廷修缮和清洁事宜的官，名宫人，世袭此职的后人便以宫为姓。
    宁：出自赢姓，春秋时期，秦国国君秦襄公的谥号为“宁”，他的后世子孙当中有的人就以先人的谥号作为姓。
    仇：出自九吾氏。
    栾：出自姬姓，发源于河北栾城一带。
    暴：最初形成于商朝，发源地在今天河南省境内。
    甘：夏朝的诸侯国当中有一个甘国，后代以国为姓。
    钭：出自姜姓。齐国的君主康公就以酒器名“钭”作为自己的姓，这样就有了钭姓。
    厉：出自姜姓。
    戎：出自姜姓。在西周时期，有一个戎国，它是齐国的附庸，后来戎国灭亡了，其公族便以国名作为了姓。
    祖：汤是商朝的开国君主，他的后人祖乙、祖辛、祖丁等都先后做了商王，其支庶子孙以“祖”作为姓。
    武：发源于今天广西省的水淳县北部。
    符：出自姬姓。
    刘：远古尧帝的子孙中，有个叫刘累的，据说他能驯化龙和驾龙飞奔，他就是刘姓始祖。
    景：在春秋时期景差的后世子孙便以景作为自己的姓，这样就有了景姓。
    詹：据传说“五帝”之一的舜，曾经封黄帝后裔中得詹（受尊敬）的人为詹姓，这样就有了詹姓。
    束：战国时期齐国有一疏姓部族，后改为束姓。
    龙：舜做部落联合首领，他的手下有一大臣名纳，为龙氏，他的后世子孙都姓龙。
    叶：发源于今天河南省的叶县。
    幸：起源据与幸臣有关。
    司：部落首领神农氏的属下当中，有专门负责占卜的大臣名司怪，他的后世子孙便以“司”作为姓。
    韶：乐官的后世子孙以其祖上所作乐曲的曲名作为自己的姓，这样就有了韶姓。
    郜：出自姬姓。
    黎：发源于今天河南省的浚县。
    蓟：发源于今天的北京市西南。
    薄：薄国君主的族人，便以封国之名作为自己的姓。
    印：源自于姬姓。春秋时期，郑穆公之子字子印，子印的孙子名段，在郑国为卿大夫，以其祖父的字中的“印”为姓，称为印氏。
    宿：伏羲氏的后裔被封在宿国（今山东东平），其后人以国名为姓。
    白：白阜被尊为白姓始祖。
    怀：是无怀氏的后人。
    蒲：舜的后代封于蒲（今山西永济），舜的后代因此以地名为姓。
    邰：帝尧任命弃大司农，封于邰（今陕西武功），其子孙以地名“邰”为姓。
    从：从姓源自于姬姓。
    鄂：春秋时，晋国大夫顷父之子嘉父叛晋，奔至鄂，称为鄂侯，他们的后代以鄂为姓。
    索：索姓是汤王的后裔。
    咸：帝喾为部落首领时，有个大臣叫咸邱黑，是咸姓的始祖。
    赖：是炎帝的后裔。
    卓：是春秋时楚国王族的后裔。
    蔺：是春秋时晋国王族的后裔。
    屠：古人有以屠宰为业者，他们的后代以屠为姓。
    蒙：颛顼的后裔。
    池：池姓源于嬴姓。
    乔：黄帝后代以山名取为桥姓，后来有的简化为乔姓。
    阴：周朝有阴邑，其大夫的后裔以食邑为姓，称阴氏。
    郁：相传大禹的老师叫郁华，他便是郁姓的始祖，其后裔以祖字为姓，称郁氏。
    胥：胥是以祖辈的名字命名的姓，起源于华胥、赫胥二氏。
    能：周成王时，大臣熊绎因功受封为男爵，他的后代将熊姓去四点改为能姓。
    苍：相传黄帝有二十五个儿子，其中有个叫苍林，他的后代以祖辈名字为姓，称苍氏。黄帝的孙子颛顼有八个儿子，都是治世能臣，世称“八恺”，其中长子名苍舒，他的后代也以祖字为姓，形成苍姓一支。大约汉代以后，苍姓改为仓姓。
    双：双姓与蒙姓同出一宗，是颛顼的后裔。夏朝建立后，封颛顼之后于蒙双，有子孙以地名为姓，成为蒙姓和双姓两支。
    闻：出自复姓闻人氏。
    莘：莘姓一族是古帝祝融的后代。
    党：党姓出自夏朝，居住在党项的王族多姓党。
    翟：翟姓出自隗姓。
    谭：谭姓是颛顼的后代。
    贡：源于端木氏。
    劳：劳姓起源于西汉时期。
    逄：逄姓出自姜姓。
    姬：相传黄帝的降生地有一条叫做“姬”的河，于是便以“姬”作为姓。
    申：申姓发源于今天河南省的南阳。
    扶：大禹任部落联盟首领的时候，其属下有扶登氏，他就是扶姓的始祖。
    堵：堵姓出自姬姓。
    冉：帝喾为炎帝部落首领时，属下的八个部落当中就有冉姓，其后人世代姓冉。
    宰：宰姓源于姬姓，春秋时期，周公孔曾经在周朝任太宰，人称宰孔，其后世子孙就以“宰”作为了姓。
    郦：郦姓出自轩辕氏。
    雍：雍姓出自轩辕氏，发源于今天河南省的内黄。
    郤：春秋时期，晋国公族子弟叔虎建立郤国，后世子孙以封地名作为姓。
    璩：古时候有一个叫蘧邑的地方，那里的人最初是以地名“蘧”作为姓的，后来蘧姓改成了璩姓。
    桑：桑姓出自金天氏。
    桂：桂姓出自姬姓。
    濮：舜任部落首领时，其子孙散封于濮地，这些人的后代便以地名作为姓。
    牛：周朝牛父的子孙以他的字“牛”作为自己的姓。
    寿：是彭祖的后裔。
    通：春秋时，巴国有大夫受封于通川，其后世子孙以封地名“通”作为姓。
    边：商代有诸侯国边国，国君为伯爵，被称为边伯，其后代称为边氏。
    扈：扈姓为大禹的后代。
    燕：南燕灭国后，伯倏的后人以国名为姓。
    冀：相传唐尧的后代被周武王分封在冀（今山西河津），其国人便以冀为姓。
    郏：周朝时，有地名称为郏鄏（今河南洛阳西）。居住在这里的人以地名为姓。
    浦：出自于姜姓。
    尚：尚姓一支为姜太公的后裔。
    农：农姓出自神农氏，是炎帝的后裔。
    温：周武王的儿子叔虞的后代被封于温（今河南温县），其后以封地为姓。
    别：《姓苑》记载别氏，京兆人，望出天水、京兆”等。
    庄：春秋时宋戴公名武庄，他的后人以其名字中的“庄”为姓。
    晏：黄帝后裔颛顼的孙子名陆终，他的儿子为晏安，其后代遂为晏姓。
    柴：柴姓出自姜姓。
    瞿：瞿姓一支源于人名，商代有一大夫，因封地在瞿上而得名瞿父，他的子孙以祖先名为姓。
    阎：上古周武王建立周朝后，武王封一位王族仲奕于阎乡，仲奕的后代以祖上封邑为姓，称阎氏。
    充：充人后代以职官名为姓。
    慕：慕姓出自慕容氏。
    连：黄帝孙子颛顼的曾孙陆终有子名惠连，他的后代以祖先名中的字为姓。
    茹：茹茹以族名为姓。
    习：古代有诸侯国习国，其国君后世子孙以习为姓。
    宦：宦姓非常罕见。
    艾：艾姓源于夏代，是禹王的后代。
    鱼：子鱼孙辈嫡传一支以祖父名字为姓，称鱼氏，支庶孙以“鱼孙”为姓。
    容：黄帝有史臣容成，其后代以容字为姓。
    向：炎帝有一个名叫向的裔孙被封为诸侯，其后代子孙便以先人的名为姓。
    古：古姓起源于殷商时期。
    易：易姓形成于春秋时期。
    慎：慎姓发源于今天安徽省的颖上县西北。
    戈：夏代东夷有寒国的儿子在戈国，其后代子孙就以国名作姓。
    廖：廖姓起源于今天的河南省唐河县西。
    庾：相传在远古帝尧时代，有掌庾大夫。以官名作为姓，这样就有了庾姓。
    终：终姓是黄帝的后裔。
    暨：暨姓是颛顼的后人。
    居：居姓出自杜姓。
    衡：出自伊姓。
    步：步姓发源于今天山西省的临汾市南。
    都：春秋初年，郑国有个公族大夫叫子都，他的子孙以其字“都”作为姓。
    耿：出自姬姓。
    满：西周胡公满的支庶子孙当中有人以先祖名字中的“满”字作为姓。
    弘：在春秋时期，卫国有个大夫叫弘演，他的后世子孙就以其名字中的“弘”字作为自己的姓。
    匡：春秋时期，鲁国大夫施孝权的家臣句须任匡邑宰，后来他的孙子就以祖父做官地的名称作为自己的姓。
    国：大禹为首领时，有一个专门掌管车马的人名叫国哀，后世子孙都随之以国为姓。
    文：周武王追谥父亲西伯姬昌为周文王，子孙以其谥号“文”作为了姓。
    寇：春秋时期卫灵公的孙子在卫国任司寇，他的后世子孙就以官名“司寇”作为自己的姓，后来简称寇氏。
    广：上古广成子的后代以广成为姓。
    禄：出自子姓，是殷商最后一个帝王纣王的后代。
    阙：阙姓起源于春秋之时。
    东：东姓源于远古之时。
    欧：春秋时，越王无疆将次子封于乌程（今浙江吴兴）欧余山的南面，古代称山南为阳，所以他被称为欧阳亭侯。
    殳：出于有虞氏。
    沃：沃丁的子孙有的以他的名字为姓，称沃氏。
    利：出于理姓，与理、李、里同宗。
    蔚：北周时设有蔚（）州，居住在这里的人以地名为姓。
    越：越国公族支庶子孙有的以原国名为姓，形成越姓。
    夔：远古时，尧和舜的乐官名叫夔，此姓的起源就在尧舜帝时代。夔原指龙形动物。
    隆：隆姓源于地名。春秋时，鲁国境内有隆邑（今山东泰安西南），居住在这里的人以其地名为姓，形成隆姓。
    师：源于技艺和职官名。
    巩：周敬王时有同族卿士简公，受封于巩（今河南巩县），称为巩简公。巩简公的子孙以封邑为姓，称巩氏。
    厍：厍姓源于北周厍狄氏所改姓。
    聂：春秋时，齐丁公封其支庶子孙于聂邑（今山东茌平西），建聂国，为齐国附庸。其后世子孙以国名为姓，形成聂姓。
    晁：源于姬姓。古代“朝”与“晁”相通，都有早晨之意，所以在姓中“朝”也写作“晁”。周朝时，景王之子王子朝的子孙以朝为姓，又称“晁”氏。
    勾：又写作“句”。其姓最早见于《山海经》：“困民之国，勾姓”。
    敖：上古五帝之一颛顼的老师叫做大敖，有的写做太敖，他的后代以祖上名字为姓，形成敖姓。
    融：融姓起源于上古，是颛顼高阳氏后裔。
    冷：冷姓系泠姓所改。
    訾或：周朝时有訾邑（今河南巩县西南），居住在这里的人有的以地名为姓。
    辛：辛姓源于姒姓。
    阚：阚姓源自姜姓。
    那：商朝君王武丁的裔孙到那地（今湖北荆门东南）定居，形成那姓。
    简：春秋时，晋国大夫狐鞫居为周文王的后裔，他被封于续，死后谥号为简。
    饶：饶姓一支源于姜姓。
    空：空姓为复姓空同、空桑、空相等省文改成。
    曾：曾参是春秋时的鲁国人，而且是孔子的得意弟子。
    毋：毋姓起源于上古，尧属下毋句制造出乐器罄，他就是毋姓的始祖。
    沙：炎帝做部落首领时，他的属下有夙沙氏，其后世子孙省文为沙氏。
    乜：产生于春秋时期，卫国有大夫的采邑在乜城，其后人就把采邑名作为了姓。
    养：春秋时期，吴国公子掩余、烛庸逃到楚国，楚王把养地（今河南境内）封给了他们，后来其子孙后代就以祖上的封地名“养”作为姓。
    鞠：鞠姓出自姬姓，周始祖弃有支孙名叫陶，他出生时手心有纹似“鞠”字形，所以取名鞠陶，他的后世子孙便以鞠作为自己的姓。
    须：须姓源自风姓，是太昊伏羲氏的后代，春秋时期有风姓国叫须句国，该国的国民则称须句氏，后来改为须氏。
    丰：春秋时期，郑穆公的儿子丰，在郑僖公时任大夫，他的孙子便以其名“丰”作为姓，而称为丰施、丰卷，后来他们的子孙也随之姓丰。
    巢：尧为帝时，有大臣巢父常居于山中，以树为巢，故称有巢氏。禹帝时曾封有巢氏之后建立巢国（今安徽境内）。在夏、商、周三代，巢国世代为诸侯国，春秋时期，楚国灭掉巢国，巢国后代公族便以原国名作为姓。
    关：夏朝时，夏桀是一个荒淫的暴君，有个叫关龙逢的贤臣曾去劝谏他，结果被处死，关龙逢的后代便姓关。
    蒯：商朝时有蒯国（在今天河南省洛阳市一带），其国人后来以国名作为姓。
    相：夏朝有一个帝王叫相，他的后裔支庶子孙，有的就以祖上的名字作为姓。
    查：查姓出自姜姓，是炎帝后裔。
    後：後姓出自太昊氏，是上古东夷部族首领太昊的孙子後照的后代。
    荆：西周初年，荆君有庶出子孙则以原国号作为姓。
    红：红姓出自熊姓。
    游：春秋时期，郑国国君郑穆公之子名偃，字子游，他的孙子以祖父的字作为姓。
    竺：汉代，有枞阳人竹晏改“竹”为“竺”，其后世子孙即沿用竺姓。
    权：商武帝武丁的后人被封于权地（今湖北境内），其后代以国为姓。
    逯：秦国公族大夫有人受封于逯邑（今陕西境内），其后世子孙以地位姓。
    盖：春秋时期公族大夫受封于盖邑（今山东沂水县西北），后代子孙就以地位姓。
    益：伯益是秦国的始祖，其支庶子孙中有人以祖上的名字作为自己的姓。
    桓：源于上古，黄帝时有大臣桓常，他是桓姓的始祖。
    公：出自姬姓。
    万俟：东晋时，鲜卑族的万俟部落随拓跋氏其部落族人以“万俟”为姓。
    司马：相传帝少昊始设司马一职，掌管军政。
    上官：春秋时期，楚庄王幼子名子兰，担任上官大夫。子兰的子孙便以地名命姓。
    欧阳：蹄被封于乌程欧余山的南面，被称为欧阳亭侯，他的支庶子孙以封地命姓。
    夏侯：杞简公的弟弟被称为夏侯，他的子孙于是以“夏侯”为姓。
    诸葛：商朝时，伯夷的后裔。
    闻人：春秋时少正卯声誉高被称做“闻人”。他的支庶子孙有的便以“闻人”为姓。
    东方：伏羲氏创八卦，八卦以东方为尊，其后代支庶子孙便以东方为姓。
    赫连：是西汉时匈奴族的姓，始祖为匈奴右贤王刘去卑。
    皇甫：春秋时宋戴公之子公子充石，字皇父。他的孙子以祖父之字为姓。
    尉迟：为鲜卑族姓。
    公羊：春秋时鲁国人公孙羊孺颇有才华，他的支庶子孙以祖上名字中的两个字命姓，形成公羊姓。公羊姓今已融入公姓。
    澹台：春秋时期，孔子有个弟子名叫澹台灭明，字子羽。
    公冶：春秋时鲁国季氏有族人叫季冶，字公冶，他的子孙便以公冶为姓。
    宗政：也作“宗正”。宗正是秦汉时期的官名，专管皇帝亲属的有关事宜，自秦始皇时开始设置。汉朝时。高祖刘邦有个本家亲戚担任宗正这一官职，后改姓为宗正。
    濮阳：濮阳为地名，在今河南濮阳县，当地人有以地名为姓的，称为濮阳氏。
    淳于：春秋时期有淳于国，淳于国的人后来称为淳于氏。
    单于：历史上匈奴族的最高首领称为“单于”，他们的后代中有以“单于”为姓的。
    太叔：春秋时，卫文公有儿子名叫太叔仪，他的后代就是太叔氏。
    申屠：为上古舜帝的后代。
    公孙：周朝国君一般立正妻所生的长子为太子，其他儿子就称为公子。公子的儿子被称为公孙。有公孙的后代就以公孙为自己的姓。
    仲孙：出自姬姓。
    轩辕：相传黄帝号轩辕氏，他的后代中有以轩辕为姓的。
    令狐：魏颗被晋君别封于令狐，“以邑为氏”而姓的令狐。
    钟离：源出于嬴姓。
    宇文：鲜卑族有个部落首领自称“字文氏”。
    长孙：北魏建立后，拓跋硅认为大伯沙莫雄的大儿子嵩是曾祖父的长孙，就赐嵩为“长孙”氏。嵩的后代也就一直以长孙为自己的姓。
    慕容：三国时期，鲜卑族首领莫护跋在棘城以北建立国家，其后代以国为姓。
    鲜于：源出子姓。
    闾丘：春秋时齐国有大夫名叫闾丘婴，他的后代称为闾丘氏。
    司徒：先秦设司徒这一官职。有的司徒后代就把官职作为自己的姓，称为司徒氏。
    司空：出自姒姓，是大禹的后代，以官职名为姓。
    佟：源于妫姓，出自夏王朝末期太史终古的后代。
    第五：源于妫姓，出自汉高祖刘邦强迁原战国时期齐国的田氏公族时封的编序，属帝王赐姓。
    言：出自春秋时言偃之后，以祖名为姓。
    福：出自春秋时齐国大夫福子丹之后，以祖名为姓。
""".strip().split()
SurNameMessage = {}

for line in _message:
    key, value = line.split('：', maxsplit=1)
    SurNameMessage[key] = value

HundredFamilyNames = """
赵	钱	孙	李	周	吴	郑	王	冯	陈	褚	卫	蒋	沈	韩	杨	朱	秦	尤	许
何	吕	施	张	孔	曹	严	华	金	魏	陶	姜	戚	谢	邹	喻	柏	水	窦	章
云	苏	潘	葛	奚	范	彭	郎	鲁	韦	昌	马	苗	凤	花	方	俞	任	袁	柳
酆	鲍	史	唐	费	廉	岑	薛	雷	贺	倪	汤	滕	殷	罗	毕	郝	邬	安	常
乐	于	时	傅	皮	卞	齐	康	伍	余	元	卜	顾	孟	平	黄	和	穆	萧	尹
姚	邵	湛	汪	祁	毛	禹	狄	米	贝	明	臧	计	伏	成	戴	谈	宋	茅	庞
熊	纪	舒	屈	项	祝	董	梁	杜	阮	蓝	闵	席	季	麻	强	贾	路	娄	危
江	童	颜	郭	梅	盛	林	刁	钟	徐	邱	骆	高	夏	蔡	田	樊	胡	凌	霍
虞	万	支	柯	昝	管	卢	莫	经	房	裘	缪	干	解	应	宗	丁	宣	贲	邓
郁	单	杭	洪	包	诸	左	石	崔	吉	钮	龚	程	嵇	邢	滑	裴	陆	荣	翁
荀	羊	於	惠	甄	麴	家	封	芮	羿	储	靳	汲	邴	糜	松	井	段	富	巫
乌	焦	巴	弓	牧	隗	山	谷	车	侯	宓	蓬	全	郗	班	仰	秋	仲	伊	宫
宁	仇	栾	暴	甘	钭	厉	戎	祖	武	符	刘	景	詹	束	龙	叶	幸	司	韶
郜	黎	蓟	薄	印	宿	白	怀	蒲	邰	从	鄂	索	咸	籍	赖	卓	蔺	屠	蒙
池	乔	阴	郁	胥	能	苍	双	闻	莘	党	翟	谭	贡	劳	逄	姬	申	扶	堵
冉	宰	郦	雍	舄	璩	桑	桂	濮	牛	寿	通	边	扈	燕	冀	郏	浦	尚	农
温	别	庄	晏	柴	瞿	阎	充	慕	连	茹	习	宦	艾	鱼	容	向	古	易	慎
戈	廖	庾	终	暨	居	衡	步	都	耿	满	弘	匡	国	文	寇	广	禄	阙	东
欧	殳	沃	利	蔚	越	夔	隆	师	巩	厍	聂	晁	勾	敖	融	冷	訾	辛	阚
那	简	饶	空	曾	毋	沙	乜	养	鞠	须	丰	巢	关	蒯	相	查	後	荆	红
游	竺	权	逯	盖	益	桓	公	万俟	司马	上官	欧阳	夏侯	诸葛
闻人	东方	赫连	皇甫	尉迟	公羊	澹台	公冶	宗政	濮阳
淳于	单于	太叔	申屠	公孙	仲孙	轩辕	令狐	钟离	宇文
长孙	慕容	鲜于	闾丘	司徒	司空	亓官	司寇	仉	督	子车
颛孙	端木	巫马	公西	漆雕	乐正	壤驷	公良	拓跋	夹谷
宰父	谷梁	晋	楚	闫	法	汝	鄢	涂	钦	段干	百里	东郭	南门
呼延	归	海	羊舌	微生	岳	帅	缑	亢	况	后	有	琴	梁丘	左丘
东门	西门	商	牟	佘	佴	伯	赏	南宫	墨	哈	谯	笪	年	爱	阳	佟
第五	言	福	百 家 姓 终
""".strip().split()
if __name__ == '__main__':
    print(SurNameMessage)
    print(SurName)
    print(HundredFamilyNames)
