#!/usr/bin/python3.7
# -*- coding: utf-8 -*-
# @Time  : 2019/4/24 17:30
# @Author: Jtyoui@qq.com

from .tool import Tool  # 常见处理字符串的工具
from .times import StringTime  # 讲口语化的时间转为标准时间
from .SentenceMake import Sentence  # 增加造句
from .captcha import Captcha  # 验证码生成器
from ._pip import pips  # 安装模块
from .timestr import *  # 时间操作
